==> apache-xtable-0.2.0-incubating.src.tgz: apache-xtable-0.2.0-incubating/xtable-api/src/main/java/org/apache/xtable/conversion/SourceTable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
package org.apache.xtable.conversion;

import java.util.Properties;

import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NonNull;

@EqualsAndHashCode(callSuper = true)
@Getter
public class SourceTable extends ExternalTable {
  /** The path to the data files, defaults to the metadataPath */
  @NonNull private final String dataPath;

  @Builder(toBuilder = true)
  public SourceTable(
      String name,
      String formatName,
      String basePath,
      String dataPath,
      String[] namespace,
      CatalogConfig catalogConfig,
      Properties additionalProperties) {
    super(name, formatName, basePath, namespace, catalogConfig, additionalProperties);
    this.dataPath = dataPath == null ? this.getBasePath() : sanitizeBasePath(dataPath);
  }
}

==> apache-xtable-0.3.0-incubating.src.tgz: apache-xtable-0.3.0-incubating/xtable-api/src/main/java/org/apache/xtable/conversion/SourceTable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
package org.apache.xtable.conversion;

import java.util.Properties;

import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NonNull;

@EqualsAndHashCode(callSuper = true)
@Getter
public class SourceTable extends ExternalTable {
  /** The path to the data files, defaults to the basePath */
  @NonNull private final String dataPath;

  @Builder(toBuilder = true)
  public SourceTable(
      String name,
      String formatName,
      String basePath,
      String dataPath,
      String[] namespace,
      CatalogConfig catalogConfig,
      Properties additionalProperties) {
    super(name, formatName, basePath, namespace, catalogConfig, additionalProperties);
    this.dataPath = dataPath == null ? this.getBasePath() : sanitizeBasePath(dataPath);
  }
}
